#
# spec file for package libcmpiutil
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcmpiutil
Version:        0.5.7
Release:        9.5
Summary:        Library of utility functions for CMPI providers
License:        LGPL-2.1-or-later
URL:            http://libvirt.org/sources/CIM/
Group:          Development/Libraries/C and C++
Source:         %{name}-%{version}.tar.bz2
Patch1:         0001-libcmpiutil-Fix-endianness-issues-in-embedded-object.patch
Patch2:         0002-fix-ARM-build.patch
Patch3:         0003-drop-duplicate-definition-of-_FORTIFY_SOURCE.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  libxml2-devel
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
BuildRequires:  pkgconfig
%else
%if 0%{?suse_version} < 920
BuildRequires:  pkgconfig
%else
BuildRequires:  pkg-config
%endif
%endif
BuildRequires:  sblim-cmpi-devel
# SLE11
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libcmpiutil is a library of utility functions for CMPI providers.  The
goal is to reduce the amount of repetitive work done in most CMPI
providers by encapsulating common procedures with more "normal" APIs.
This extends from operations like getting typed instance properties to
standardizing method dispatch and argument checking.

%package -n libcmpiutil0
Summary:        Library of utility functions for CMPI providers
Group:          Development/Libraries/C and C++
Obsoletes:      libcmpiutil < %{version}-%{release}

%description -n libcmpiutil0
Libcmpiutil is a library of utility functions for CMPI providers.  The
goal is to reduce the amount of repetitive work done in most CMPI
providers by encapsulating common procedures with more "normal" APIs.
This extends from operations like getting typed instance properties to
standardizing method dispatch and argument checking.

%package devel
Summary:        Library of utility functions for CMPI providers
Group:          Development/Libraries/C and C++
Requires:       libcmpiutil0 = %{version}-%{release}
Requires:       sblim-cmpi-devel

%description devel
Libcmpiutil is a library of utility functions for CMPI providers.  The
goal is to reduce the amount of repetitive work done in most CMPI
providers by encapsulating common procedures with more "normal" APIs.
This extends from operations like getting typed instance properties to
standardizing method dispatch and argument checking.

%prep
%setup -q
%patch1 -p1
%ifarch %arm
%patch2 -p1
%endif
%patch3 -p1
chmod -x *.c *.y *.h *.l

%build
export CFLAGS="%{optflags} -fgnu89-inline"
rm -f aclocal.m4 configure Makefile.in
touch AUTHORS ChangeLog NEWS
autoupdate acinclude.m4 configure.ac Makefile.am
autoreconf -fi
%configure --enable-static=no
%if 0%{?make_build:1}
%make_build
%else
make %{?_smp_mflags}
%endif

%install
%makeinstall
rm -f %{buildroot}/%{_libdir}/*.{a,la}

%post   -n libcmpiutil0 -p /sbin/ldconfig
%postun -n libcmpiutil0 -p /sbin/ldconfig

%files -n libcmpiutil0
%defattr(-, root, root, -)
%doc doc/doxygen.conf doc/mainpage README COPYING
%{_libdir}/lib*.so.*

%files devel
%defattr(-, root, root, -)
%{_libdir}/lib*.so
%dir %{_includedir}/libcmpiutil
%{_includedir}/libcmpiutil/*.h
%{_libdir}/pkgconfig/libcmpiutil.pc
%doc doc/SubmittingPatches

%changelog
* Thu Jun 23 2022 Klaus Kämpf <kkaempf@suse.com>
- adapt to latest autotools
- rename fix-arm.patch to 0002-fix-ARM-build.patch
- add 0003-drop-duplicate-definition-of-_FORTIFY_SOURCE.patch
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libcmpiutil.x86_64: E:
  shlib-policy-name-error SONAME: libcmpiutil.so.0, expected
  package suffix: 0"
- Throw out old specfile constructs
* Tue Jun  9 2015 schwab@suse.de
- Force gnu89 inline semantics
* Mon Feb 17 2014 kkaempf@suse.com
- add upstream patch
  0001-libcmpiutil-Fix-endianness-issues-in-embedded-object.patch
* Mon Apr 15 2013 kkaempf@suse.com
- Update to 0.5.7
  * patches about log fix and improvement (Wenchao Xia).
* Thu Aug 16 2012 agraf@suse.com
- fix arm build
* Thu Jun 16 2011 jfehlig@novell.com
- Update to 0.5.6
  * build cleanups (Eduardo Lima)
* Fri Jan 28 2011 kkaempf@novell.com
- Update to 0.5.5
  * Restore const to interface to avoid warnings (Chip Vincent)
  * Add method to merge RASDs (Sharad Mishra)
  * Missing namespace from migration indications (Sharad Mishra)
  * Adding CMReturnDone after CMPI InvokeMethod (Sharad Mishra)
* Tue Nov 30 2010 kkaempf@novell.com
- Update to 0.5.3
* Mon Aug  2 2010 kkaempf@novell.com
- Fix the build for other distributions
* Fri Aug  7 2009 jfehlig@novell.com
- Support for read/write array of strings to properties that
  expect them
- Workaround for sfcb's lack of association handling
* Thu Oct 23 2008 jfehlig@novell.com
- Updated to head of libcmpiutil, c/s 85:5fbf96fedcf7
  bnc#437816
* Mon Jul 28 2008 jfehlig@novell.com
- Updated to head of libcmpiutil, 0.5 pre-release.
  - fixes for indication enable/disable
* Fri Jul 18 2008 jfehlig@novell.com
- Removed ExclusiveArch restriction
* Thu Jun 26 2008 jfehlig@novell.com
- Updated to official 0.4 release
* Thu May  1 2008 jfehlig@novell.com
- Initial creation of package
